import os

cache_root = os.path.join(os.path.dirname(__file__), 'cache')  # cache catalog
cache_commands = os.path.join(cache_root, 'commands.json')      # cache commands file
cache_projects = os.path.join(cache_root, 'projects.json')      # cache projects file
